@@ -1,5 +1,5 @@
 package Dist::Zilla::Role::ModuleIncluder;
-$Dist::Zilla::Role::ModuleIncluder::VERSION = '0.006';
+$Dist::Zilla::Role::ModuleIncluder::VERSION = '0.007';
 # vim: ts=4 sts=0 sw=0 noet
 use Moose::Role;
 use MooseX::Types::Moose qw/Bool/;
@@ -8,7 +8,7 @@ use Dist::Zilla::File::InMemory 5.000;
 use File::Slurper 'read_binary';
 use Scalar::Util qw/reftype/;
 use List::Util 1.45 'uniq';
-use Module::CoreList;
+use Module::CoreList 5.20160520;
 use Module::Metadata;
 use Perl::PrereqScanner;
 
@@ -38,17 +38,34 @@ has include_dependencies => (
 		my $module = shift;
 		return $module_files{$module} if exists $module_files{$module};
 		$module_files{$module} = Module::Metadata->find_module_by_name($module)
-			or confess "Could not find module $module";
+			or confess "Can't locate $module";
 	}
 }
 
+around dump_config => sub
+{
+	my ($orig, $self) = @_;
+	my $config = $self->$orig;
+
+	my $data = {
+		version => __PACKAGE__->VERSION || '<self>',
+		include_dependencies => ($self->include_dependencies ? 1 : 0),
+		'Module::CoreList' => Module::CoreList->VERSION,
+	};
+	$config->{+__PACKAGE__} = $data;
+
+	return $config;
+};
+
 sub _get_reqs {
 	my ($self, $reqs, $scanner, $module, $background, $blacklist) = @_;
 	my $module_file = _find_module_by_name($module);
 	my %new_reqs = %{ $scanner->scan_file($module_file)->as_string_hash };
 	$self->log_debug([ 'found dependency of %s: %s %s', $module, $_, $new_reqs{$_} ]) foreach keys %new_reqs;
 
-	my @real_reqs = grep { !$blacklist->{$_} && !Module::CoreList::is_core($_, $new_reqs{$_}, $background) } keys %new_reqs;
+	my @real_reqs = grep {
+		!$blacklist->{$_} && !Module::CoreList::is_core($_, $new_reqs{$_} ? $new_reqs{$_} : undef, $background)
+	} keys %new_reqs;
 	for my $req (@real_reqs) {
 		if (defined $reqs->{$module}) {
 			next if $reqs->{$module} >= $new_reqs{$req};
@@ -104,7 +121,7 @@ Dist::Zilla::Role::ModuleIncluder - Include modules and their dependencies in in
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 DESCRIPTION
 
